==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DownwardAPIVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource,io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceBuilder>{
  public DownwardAPIVolumeSourceBuilder() {
    this(false);
  }
  public DownwardAPIVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new DownwardAPIVolumeSource(), validationEnabled);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DownwardAPIVolumeSource(), validationEnabled);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance) {
    this(fluent, instance, false);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDefaultMode(instance.getDefaultMode()); 
    fluent.withItems(instance.getItems()); 
    this.validationEnabled = validationEnabled; 
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance) {
    this(instance,false);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDefaultMode(instance.getDefaultMode()); 
    this.withItems(instance.getItems()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource build() {
    DownwardAPIVolumeSource buildable = new DownwardAPIVolumeSource(fluent.getDefaultMode(),fluent.getItems());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DownwardAPIVolumeSourceBuilder that = (DownwardAPIVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DownwardAPIVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource,io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceBuilder>{
  public DownwardAPIVolumeSourceBuilder() {
    this(false);
  }
  public DownwardAPIVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new DownwardAPIVolumeSource(), validationEnabled);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DownwardAPIVolumeSource(), validationEnabled);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance) {
    this(fluent, instance, false);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDefaultMode(instance.getDefaultMode()); 
    fluent.withItems(instance.getItems()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance) {
    this(instance,false);
  }
  public DownwardAPIVolumeSourceBuilder(io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDefaultMode(instance.getDefaultMode()); 
    this.withItems(instance.getItems()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.DownwardAPIVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeSource build() {
    DownwardAPIVolumeSource buildable = new DownwardAPIVolumeSource(fluent.getDefaultMode(),fluent.getItems());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DownwardAPIVolumeSourceBuilder that = (DownwardAPIVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
